OC.L10N.register(
    "dav",
    {
    "Calendar" : "カレンダー",
    "Tasks" : "タスク",
    "Personal" : "個人",
    "{actor} created calendar {calendar}" : "{actor}はカレンダー {calendar} を作成しました",
    "You created calendar {calendar}" : "カレンダー {calendar} を作成しました",
    "{actor} deleted calendar {calendar}" : "{actor}はカレンダー {calendar} を削除しました",
    "You deleted calendar {calendar}" : "カレンダー {calendar} を削除しました",
    "{actor} updated calendar {calendar}" : "{actor}はカレンダー {calendar} を更新しました",
    "You updated calendar {calendar}" : "カレンダー {calendar} を更新しました",
    "{actor} restored calendar {calendar}" : "{actor} がカレンダー {calendar}を復元しました",
    "You restored calendar {calendar}" : "カレンダー {calendar}を復元しました",
    "You shared calendar {calendar} as public link" : "カレンダー{calendar}を公開リンクとして共有しました",
    "You removed public link for calendar {calendar}" : "カレンダー{calendar}の公開リンクを削除しました",
    "{actor} shared calendar {calendar} with you" : "{actor} が カレンダー{calendar} を あなたと共有しました",
    "You shared calendar {calendar} with {user}" : " カレンダー{calendar} を {user} と共有しました",
    "{actor} shared calendar {calendar} with {user}" : "{actor} が カレンダー{calendar} を {user} と共有しました",
    "{actor} unshared calendar {calendar} from you" : "{actor} が あなたからカレンダー{calendar} を共有解除しました",
    "You unshared calendar {calendar} from {user}" : "{user}からカレンダー{calendar} を共有解除しました",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} が  {user} からカレンダー{calendar} を共有解除しました",
    "{actor} unshared calendar {calendar} from themselves" : "{actor}がカレンダー{calendar} を共有解除しました",
    "You shared calendar {calendar} with group {group}" : " カレンダー{calendar} を グループ{group} と共有しました",
    "{actor} shared calendar {calendar} with group {group}" : " {actor}がカレンダー{calendar} を グループ{group} と共有しました",
    "You unshared calendar {calendar} from group {group}" : "グループ{group}からカレンダー{calendar}の共有を解除しました",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor}がグループ{group}からカレンダー{calendar}の共有を解除しました",
    "Untitled event" : "無題のイベント",
    "{actor} created event {event} in calendar {calendar}" : "{actor}はカレンダー {calendar} のイベント{event}を作成しました",
    "You created event {event} in calendar {calendar}" : "カレンダー {calendar} のイベント{event}を作成しました",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor}はカレンダー {calendar} のイベント{event}を削除しました",
    "You deleted event {event} from calendar {calendar}" : "カレンダー {calendar} のイベント{event}を削除しました",
    "{actor} updated event {event} in calendar {calendar}" : "{actor}はカレンダー {calendar} のイベント{event}を更新しました",
    "You updated event {event} in calendar {calendar}" : "カレンダー {calendar} のイベント{event}を更新しました",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} はイベント {event} をカレンダー {sourceCalendar} からカレンダー {targetCalendar} に移動しました。",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "あなたはイベント {event} をカレンダー {sourceCalendar} からカレンダー {targetCalendar} に移動しました。",
    "{actor} restored event {event} of calendar {calendar}" : "{actor}はカレンダー {calendar}のイベント {event}を復元しました",
    "You restored event {event} of calendar {calendar}" : "カレンダー {calendar} のイベント {event}を復元しました",
    "Busy" : "ビジー",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} がリスト {calendar} に ToDo {todo} を作成しました",
    "You created to-do {todo} in list {calendar}" : "あなたはリスト {calendar} に ToDo {todo} を作成しました",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} は {calendar} リストから {todo} のToDoを削除しました",
    "You deleted to-do {todo} from list {calendar}" : "あなたはリスト {calendar} からToDo {todo} を削除しました",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} がリスト {calendar} のToDo {todo} を更新しました",
    "You updated to-do {todo} in list {calendar}" : "あなたはリスト {calendar} の ToDo {todo} を更新しました",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} が {calendar} リストの {todo} を解決しました",
    "You solved to-do {todo} in list {calendar}" : "あなたは {calendar} リストの {todo} を解決しました",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} がリスト {calendar} の ToDo {todo} を再開しました",
    "You reopened to-do {todo} in list {calendar}" : "あなたはリスト {calendar} の ToDo {todo} を再開しました",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} は {sourceCalendar} リストから {targetCalendar} リストに ToDo {todo} を移動しました",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "あなたは {sourceCalendar} リストから {targetCalendar} リストに ToDo {todo} を移動しました",
    "Calendar, contacts and tasks" : "カレンダー、連絡帳とタスク",
    "A <strong>calendar</strong> was modified" : "<strong>カレンダー</strong>が変更されたとき",
    "A calendar <strong>event</strong> was modified" : "カレンダーの<strong>イベント</strong>が変更されたとき",
    "A calendar <strong>to-do</strong> was modified" : "カレンダーの<strong>ToDo</strong>が変更されました",
    "Contact birthdays" : "誕生日",
    "Death of %s" : "%sの命日",
    "Untitled calendar" : "無題のカレンダー",
    "Calendar:" : "カレンダー:",
    "Date:" : "日付:",
    "Where:" : "場所:",
    "Description:" : "説明:",
    "_%n year_::_%n years_" : ["%n年"],
    "_%n month_::_%n months_" : ["%nヶ月"],
    "_%n day_::_%n days_" : ["%n日"],
    "_%n hour_::_%n hours_" : ["%n時間"],
    "_%n minute_::_%n minutes_" : ["%n分"],
    "%s (in %s)" : "%s（%s後）",
    "%s (%s ago)" : "%s（%s前）",
    "Calendar: %s" : "カレンダー:%s",
    "Date: %s" : "日付:%s",
    "Description: %s" : "説明:%s",
    "Where: %s" : "場所:%s",
    "%1$s via %2$s" : "%1$s に %2$s から",
    "In the past on %1$s for the entire day" : "過去に%1$sで終日",
    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["終日%1$sの%n分"],
    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["終日%1$sの%n時間"],
    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["終日%1$sの%n日"],
    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["終日%1$sの%n週間"],
    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["終日%1$sの%nヶ月"],
    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["終日%1$sの%n年間"],
    "In the past on %1$s between %2$s - %3$s" : "過去%1$s、%2$s～%3$sの間",
    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["%2$s～%3$sの間の%1$sの%n分"],
    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["%2$s～%3$sの間の%1$sの%n時間"],
    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["%2$s～%3$sの間の%1$sの%n日間"],
    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["%2$s～%3$sの間の%1$sの%n週間"],
    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["%2$s～%3$sの間の%1$sの%nヶ月"],
    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["%2$s～%3$sの間の%1$sの%n年間"],
    "Could not generate when statement" : "when文を生成できませんでした",
    "Every Day for the entire day" : "毎日、終日",
    "Every Day for the entire day until %1$s" : "%1$sまでの終日、毎日",
    "Every Day between %1$s - %2$s" : "%1$sから%2$sの間の毎日",
    "Every Day between %1$s - %2$s until %3$s" : "%1$sから%2$sの間で%3$sまで毎日",
    "Every %1$d Days for the entire day" : "%1$d日ごとに終日",
    "Every %1$d Days for the entire day until %2$s" : "%1$d日ごと、%2$sまで終日",
    "Every %1$d Days between %2$s - %3$s" : "%2$s～%3$sの間で%1$d日ごと",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "%1$d日ごと %2$s～%3$sの間、%4$sまで",
    "Could not generate event recurrence statement" : "イベントの再帰ステートメントを生成できませんでした",
    "Every Week on %1$s for the entire day" : "毎週%1$sで終日",
    "Every Week on %1$s for the entire day until %2$s" : "毎週%1$sに%2$sまで終日",
    "Every Week on %1$s between %2$s - %3$s" : "毎週%1$s、%2$s～%3$sの間",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "毎週%1$s、%2$s～%3$sの間に%4$sまで",
    "Every %1$d Weeks on %2$s for the entire day" : "%1$d週ごと%2$sで終日",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "%1$d週ごと%2$sに%3$sまで終日",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "%1$d週ごとの%2$s %3$s～%4$sの間",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "%1$d週ごと%2$s %5$sまで%3$s～%4$sの間",
    "Every Month on the %1$s for the entire day" : "毎月%1$sに終日",
    "Every Month on the %1$s for the entire day until %2$s" : "毎月%1$s、%2$sまでの終日",
    "Every Month on the %1$s between %2$s - %3$s" : "毎月%2$s～%3$sの間の%1$s",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "毎月、%2$s～%3$sの間の%1$sに、%4$sまで",
    "Every %1$d Months on the %2$s for the entire day" : "%1$dカ月ごとの%2$sに終日",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "%1$dカ月ごとの%2$s、%3$sまで終日",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "%1$dカ月ごとの%2$s、%3$s～%4$sの間",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "%1$dカ月ごとの%2$s、%3$s～%4$sの間、%5$sまで",
    "Every Year in %1$s on the %2$s for the entire day" : "毎年%1$s %2$sに終日",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "毎年%1$s %2$s %3$sまで終日",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "毎年%1$s %2$s %3$s～%4$sの間の終日",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "毎年%1$s %2$s %3$s～ %4$s %5$sまで　",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "%1$d年ごとの%2$s %3$sの終日",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "%1$d年ごとの%2$s %3$s %4$sまでの終日",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "%1$d年ごとの%2$s %3$s %4$s～%5$sの間",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "%1$d年ごとの%2$s %3$s %4$s～%5$sの間、%6$sまで",
    "On specific dates for the entire day until %1$s" : "%1$sまでの特定の日付の終日",
    "On specific dates between %1$s - %2$s until %3$s" : "%1$s～%2$sの間、%3$sまでの特定の日付",
    "In the past on %1$s" : "過去%1$s",
    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["%1$sの%n分間"],
    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["%1$sの%n時間"],
    "_In a day on %1$s_::_In %n days on %1$s_" : ["%1$sの%n日間"],
    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["%1$sの%n週間"],
    "_In a month on %1$s_::_In %n months on %1$s_" : ["%1$sの%nヶ月"],
    "_In a year on %1$s_::_In %n years on %1$s_" : ["%1$sの%n年間"],
    "In the past on %1$s then on %2$s" : "過去%1$s、その後%2$s",
    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["過去%1$sの%n分間、その後%2$s"],
    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["過去%1$sの%n時間、その後%2$s"],
    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["過去%1$sの%n日間、その後%2$s"],
    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["過去%1$sの%n週間、その後%2$s"],
    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["過去%1$sの%nヶ月、その後%2$s"],
    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["過去%1$sの%n年間、その後%2$s"],
    "In the past on %1$s then on %2$s and %3$s" : "過去%1$s、その後%2$sと%3$s",
    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["%1$sの%n分間、その後%2$sと%3$s"],
    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["%1$sの%n時間、その後%2$sと%3$s"],
    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["%1$sの%n日間、その後%2$sと%3$s"],
    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["%1$sの%n週間、その後%2$sと%3$s"],
    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["%1$sの%nヶ月、その後%2$sと%3$s"],
    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["%1$sの%n年間、その後%2$sと%3$s"],
    "Could not generate next recurrence statement" : "次の再帰ステートメントを生成できませんでした",
    "Cancelled: %1$s" : "キャンセル: %1$s",
    "\"%1$s\" has been canceled" : "%1$sはキャンセルされました",
    "Re: %1$s" : "更新: %1$s",
    "%1$s has accepted your invitation" : "%1$sが招待を受け付けました",
    "%1$s has tentatively accepted your invitation" : "%1$sはあなたの招待を暫定承諾しました",
    "%1$s has declined your invitation" : "%1$sはあなたの招待を受けつけませんでした",
    "%1$s has responded to your invitation" : "%1$sはあなたの招待に応じました",
    "Invitation updated: %1$s" : "招待状が更新されました: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$sによりイベント\"%2$s\"が更新されました",
    "Invitation: %1$s" : "招待: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$sから \"%2$s\" に招待されました",
    "Organizer:" : "主催者:",
    "Attendees:" : "参加者:",
    "Title:" : "タイトル:",
    "When:" : "いつ:",
    "Location:" : "場所：",
    "Link:" : "リンク:",
    "Occurring:" : "発生:",
    "Accept" : "承諾",
    "Decline" : "拒否",
    "More options …" : "他のオプション …",
    "More options at %s" : "%s のその他のオプション",
    "Monday" : "月曜日",
    "Tuesday" : "火曜日",
    "Wednesday" : "水曜日",
    "Thursday" : "木曜日",
    "Friday" : "金曜日",
    "Saturday" : "土曜日",
    "Sunday" : "日曜日",
    "January" : "1月",
    "February" : "2月",
    "March" : "3月",
    "April" : "4月",
    "May" : "5月",
    "June" : "6月",
    "July" : "7月",
    "August" : "8月",
    "September" : "9月",
    "October" : "10月",
    "November" : "11月",
    "December" : "12月",
    "First" : "第1",
    "Second" : "第2",
    "Third" : "第3",
    "Fourth" : "第4",
    "Fifth" : "5日目",
    "Last" : "最後",
    "Second Last" : "最後から2番目",
    "Third Last" : "最後から3番目",
    "Fourth Last" : "最後から4番目",
    "Fifth Last" : "最後から5日目",
    "Contacts" : "連絡先",
    "{actor} created address book {addressbook}" : "{actor}がアドレス帳 {addressbook}を作成しました",
    "You created address book {addressbook}" : "アドレス帳 {addressbook}を作成しました",
    "{actor} deleted address book {addressbook}" : "{actor}がアドレス帳 {addressbook}を削除しました",
    "You deleted address book {addressbook}" : "アドレス帳 {addressbook}を削除しました",
    "{actor} updated address book {addressbook}" : "{actor}がアドレス帳 {addressbook}を更新しました",
    "You updated address book {addressbook}" : "アドレス帳 {addressbook}を更新しました",
    "{actor} shared address book {addressbook} with you" : "{actor}がアドレス帳 {addressbook}をあなたに共有しました",
    "You shared address book {addressbook} with {user}" : "アドレス帳 {addressbook}を{user}に共有しました",
    "{actor} shared address book {addressbook} with {user}" : "{actor}がアドレス帳 {addressbook}を{user}に共有しました",
    "{actor} unshared address book {addressbook} from you" : "{actor}があなたからのアドレス帳 {addressbook}の共有を解除しました",
    "You unshared address book {addressbook} from {user}" : "{user}からのアドレス帳 {addressbook}の共有を解除しました",
    "{actor} unshared address book {addressbook} from {user}" : "{actor}が{user}へのアドレス帳 {addressbook}の共有を解除しました",
    "{actor} unshared address book {addressbook} from themselves" : "{actor}が彼らへのアドレス帳 {addressbook}の共有を解除しました",
    "You shared address book {addressbook} with group {group}" : "アドレス帳 {addressbook}をグループ {group}へ共有しました",
    "{actor} shared address book {addressbook} with group {group}" : "{actor}がアドレス帳 {addressbook}をグループ {group}へ共有しました",
    "You unshared address book {addressbook} from group {group}" : "グループ {group}からのアドレス帳 {addressbook}の共有を解除しました",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} がグループ {group}からのアドレス帳 {addressbook}の共有を解除しました",
    "{actor} created contact {card} in address book {addressbook}" : "{actor}がアドレス帳 {addressbook}に連絡先 {card}を追加しました",
    "You created contact {card} in address book {addressbook}" : "アドレス帳 {addressbook}に連絡先 {card}を追加しました",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor}がアドレス帳 {addressbook}から連絡先 {card}を削除しました",
    "You deleted contact {card} from address book {addressbook}" : "アドレス帳 {addressbook}から連絡先 {card}を削除しました",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor}がアドレス帳 {addressbook}の連絡先 {card}を更新しました",
    "You updated contact {card} in address book {addressbook}" : "アドレス帳 {addressbook}の連絡先 {card}を更新しました",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "連絡先やアドレス帳が変更されたとき",
    "Accounts" : "アカウント",
    "System address book which holds all accounts" : "全アカウントが記録されているシステムアドレス帳",
    "File is not updatable: %1$s" : "ファイルが更新できません:%1$s",
    "Failed to get storage for file" : "ファイルのストレージを取得できませんでした",
    "Could not write to final file, canceled by hook" : "最終ファイルへの書き込みができなかったため、フックによりキャンセルされた",
    "Could not write file contents" : "ファイルの内容を書き込むことができませんでした",
    "_%n byte_::_%n bytes_" : ["%n bytes"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "ファイルをコピー先へコピー中にエラーが発生しました (コピー済: %1$s, 想定ファイルサイズ: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Nextcloudクライアントからの想定ファイルサイズは、%1$s ですが、Nextcloudストレージへの書き込みファイルサイズは %2$s でした。送信側のネットワークの問題またはサーバー側のストレージへの書き込みに問題がある可能性があります。",
    "Could not rename part file to final file, canceled by hook" : "最終ファイルの名前の変更が出来なかったため、フックによりキャンセルされました",
    "Could not rename part file to final file" : "最終ファイルの名前の変更が出来ませんでした",
    "Failed to check file size: %1$s" : "ファイルサイズの確認に失敗: %1$s",
    "Could not open file: %1$s, file does seem to exist" : "ファイルを開けませんでした： %1$s、ファイルは存在するようです",
    "Could not open file: %1$s, file doesn't seem to exist" : "ファイルを開けませんでした： %1$s ファイルが存在しないようです。",
    "Encryption not ready: %1$s" : "暗号化の準備が出来ていません: %1$s",
    "Failed to open file: %1$s" : "ファイルを開くのに失敗: %1$s",
    "Failed to unlink: %1$s" : "リンクの解除に失敗: %1$s",
    "Failed to write file contents: %1$s" : "ファイルの内容の書き込みに失敗: %1$s",
    "File not found: %1$s" : "ファイルが見つかりません: %1$s",
    "Invalid target path" : "無効なターゲットパス",
    "System is in maintenance mode." : "システムはメンテナンスモードです。",
    "Upgrade needed" : "アップグレードが必要です",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "iOS / macOSでCalDAVおよびCardDAVを使用するには、%sにHTTPSを設定する必要があります。",
    "Configures a CalDAV account" : "CalDAVアカウントを設定します",
    "Configures a CardDAV account" : "CardDAVアカウントを設定します",
    "Events" : "イベント",
    "Untitled task" : "タイトルなしタスク",
    "Completed on %s" : "%sに完了",
    "Due on %s by %s" : "期限日%s が%sにより設定",
    "Due on %s" : "期限日：%s",
    "System Address Book" : "システム連絡先リスト",
    "The system address book contains contact information for all users in your instance." : "システムのアドレス帳には、インスタンスのすべてのユーザーの連絡先情報が含まれています。",
    "Enable System Address Book" : "システム連絡先リストを有効にする",
    "DAV system address book" : "DAVシステムアドレス帳",
    "No outstanding DAV system address book sync." : "DAVシステムアドレス帳の同期が完了していません。",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAVシステムのアドレス帳同期は、インスタンスに1000人以上のユーザーがいるか、エラーが発生したためまだ実行されていません。手動で実行するには、\"occ dav:sync-system-addressbook\"を呼び出してください。",
    "WebDAV endpoint" : "WebDAVエンドポイント",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "WebDAVでのファイル同期を許可するようにWebサーバーが正しく設定されているか確認できませんでした。手動で確認してください。",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "WebDAVインターフェースが動作していないようです。Webサーバーは、ファイルの同期を許可するよう適切に設定されていません。",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "WebDAVによるファイル同期を許可するように、Webサーバーが適切に設定されています。",
    "Migrated calendar (%1$s)" : "カレンダーを移行しました (%1$s)",
    "Calendars including events, details and attendees" : "カレンダーには、イベント、イベントの詳細及び出席者が含まれます",
    "Contacts and groups" : "連絡先とグループ",
    "WebDAV" : "WebDAV",
    "Absence saved" : "不在を保存しました",
    "Failed to save your absence settings" : "不在設定の保存に失敗しました",
    "Absence cleared" : "不在を削除しました",
    "Failed to clear your absence settings" : "不在設定の解除に失敗しました",
    "First day" : "初日",
    "Last day (inclusive)" : "最終日（含む）",
    "Out of office replacement (optional)" : "不在時の代理者（オプション）",
    "Name of the replacement" : "交代要員の氏名",
    "No results." : "結果はありません。",
    "Start typing." : "入力を開始する。",
    "Short absence status" : "短い不在のステータス",
    "Long absence Message" : "長期不在のメッセージ",
    "Save" : "保存",
    "Disable absence" : "不在を無効にする",
    "Failed to load availability" : "可用性の読み込みに失敗",
    "Saved availability" : "可用性を保存しました",
    "Failed to save availability" : "可用性を保存しました",
    "Time zone:" : "タイムゾーン：",
    "to" : "宛先",
    "Delete slot" : "スロットを削除",
    "No working hours set" : "勤務時間未設定",
    "Add slot" : "スロットを追加",
    "Weekdays" : "平日",
    "Pick a start time for {dayName}" : "{dayName} 開始時間を指定してください",
    "Pick a end time for {dayName}" : "{dayName} の終了時間を指定してください",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "利用時間外は自動的にユーザーステータスを\"非通知\" に設定し、すべての通知をミュートします。",
    "Availability" : "応対可能日時",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "勤務時間を設定すると、他のユーザが会議を予約する際に、あなたがいつ不在であるかがわかります。",
    "Absence" : "不在",
    "Configure your next absence period." : "次の不在期間を設定します。",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "{calendarappstoreopen}カレンダーアプリ{linkclose}、または{calendardocopen}を同期させるためにデスクトップとモバイルを接続する ↗{linkclose}もインストールしてください。",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "{emailopen}メールサーバー{linkclose}を正しく設定してください。",
    "Calendar server" : "カレンダーサーバー",
    "Send invitations to attendees" : "参加者に招待状を送信する",
    "Automatically generate a birthday calendar" : "自動的に誕生日カレンダーを生成する",
    "Birthday calendars will be generated by a background job." : "誕生日カレンダーは、バックグラウンドジョブによって生成されます。",
    "Hence they will not be available immediately after enabling but will show up after some time." : "したがって、有効にした直後は利用できませんが、しばらくしてから表示されます。",
    "Send notifications for events" : "イベントの通知を送信",
    "Notifications are sent via background jobs, so these must occur often enough." : "通知はバックグラウンドジョブを介して送信されるため、十分な頻度で発生します。",
    "Send reminder notifications to calendar sharees as well" : "カレンダー共有にもリマインダー通知を送信する",
    "Reminders are always sent to organizers and attendees." : "リマインダーを常に作成者と出席者に送信します。",
    "Enable notifications for events via push" : "イベントのプッシュ通知を有効にする",
    "There was an error updating your attendance status." : "出席状況の更新中にエラーが発生しました。",
    "Please contact the organizer directly." : "主催者に直接お問い合わせください。",
    "Are you accepting the invitation?" : "招待を受け入れていますか？",
    "Tentative" : "暫定的",
    "Your attendance was updated successfully." : "出席は正常に更新されました。",
    "Time:" : "時刻:",
    "Could not open file" : "ファイルを開くことができませんでした",
    "Invalid chunk name" : "無効なチャンク名",
    "Could not rename part file assembled from chunks" : "チャンクから構成されている部分ファイルの名前の変更ができませんでした"
},
"nplurals=1; plural=0;");
